@@ -35,26 +35,26 @@ def query_yes_no(question, default="yes"):
             sys.stdout.write("Please respond with 'yes' or 'no' "\
                              "(or 'y' or 'n').\n")
 
-class MySQLRocketDB:
-	name = ""
-	size = ""
-	tables_number = ""
-	rows_number = ""
+class MySQLRocketDB(object):
+	def __init__(self):
+		self.name = ""
+		self.size = ""
+		self.tables_number = ""
+		self.rows_number = ""
 
-class MySQLRocket:
-	name = "default"
-	host = "localhost"
-	user = "root"
-	port = 3306
-	password = ""
-	mysqldump = "/usr/bin/mysqldump"
-	config = ConfigParser.ConfigParser()
-	configfile = ""
+class MySQLRocket(object):
+	appname = "mysqlrocket"
+	appauthor = ressources.__author__
 
 	def __init__(self):
-		appname = "mysqlrocket"
-		appauthor = ressources.__author__
-		self.config_file= os.path.join(user_data_dir(appname, appauthor), 'mysqlrocket.cfg')
+		self.name = "default"
+		self.host = "localhost"
+		self.user = "root"
+		self.port = 3306
+		self.password = ""
+		self.mysqldump = "/usr/bin/mysqldump"
+		self.config = ConfigParser.ConfigParser()
+		self.config_file= os.path.join(user_data_dir(self.appname, self.appauthor), 'mysqlrocket.cfg')
 		self.config.read(self.config_file)
 
 	def config_remove(self, config_id):
@@ -121,6 +121,9 @@ class MySQLRocket:
 				print 'Error database already exist!'
 				sys.exit(1)
 		db_user=db_name
+		if len(db_user)>16:
+			print 'ERROR user name (same as datatabase name) cannot exceed 16 characters (MySQL restriction)'
+			sys.exit(1)
 		dictionnary=string.ascii_letters+string.digits # alphanumeric, upper and lowercase
 		if db_password=='':
 			db_password="".join([random.choice(dictionnary) for i in range(8)])
@@ -136,26 +139,37 @@ class MySQLRocket:
 			print "Database creation fail"
 			print('Error %d: %s' % (e.args[0], e.args[1]))
 			sys.exit(1)
-		print '##################################'			
-		print "Database was successfully created!"
-		print '##################################'
-		print "Host: "+self.host
-		print "Database name: "+db_name
-		print "User name: "+db_user
-		print "User password: "+db_password
-		print "DSN: mysql://"+db_user+":"+db_password+"@"+self.host+"/"+db_name
-		print '##################################'
+		print "-"*50		
+		print "| {0:46} |".format("Database was successfully created!")
+		print "-"*50
+		print "| {0:46} |".format("Host: "+self.host)
+		print "| {0:46} |".format("Database name: "+db_name)
+		print "| {0:46} |".format("User name: "+db_user)
+		print "| {0:46} |".format("User password: "+db_password)
+		print "| {0:46} |".format("DSN: mysql://"+db_user+":"+db_password+"@"+self.host+"/"+db_name)
+		print "-"*50
 
-	def ls(self, db_pattern='%'):
+	def ls(self, db_pattern='%', db_extend=False):
 		db_list=self.showdb(db_pattern)
-		print "-"*80
-		print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format("Database", "Tables number", "Rows number", "Size (MB)")
-		print "-"*80
 		db_list.sort()
+		if db_extend:
+			print "-"*80
+			print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format("Database", "Tables number", "Rows number", "Size (MB)")
+			print "-"*80
+		else:
+			print "-"*31
+			print '| {0:28}|'.format("Database")
+			print "-"*31
 		for database in db_list:
-			db=self.get_db_properties(database)
-			print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format(db.name[:20], db.tables_number [:20], db.rows_number[:8], db.size[:30])
-		print "-"*80	
+			if db_extend:
+				db=self.get_db_properties(database)
+				print '| {0:28}| {1:16}| {2:15}| {3:12}|'.format(db.name[:20], db.tables_number [:20], db.rows_number[:8], db.size[:30])
+			else:
+				print '| {0:28}|'.format(database[:20])
+		if db_extend:
+			print "-"*80
+		else:
+			print "-"*31
 
 	def showdb(self, db_pattern='%'):
 		db_list=[]
@@ -173,7 +187,6 @@ class MySQLRocket:
 		return db_list
 
 	def rm(self, db_name):
-		print db_name
 		print 'Database "{database_name}" will be deleted'.format(database_name=db_name)
 		areyousure=query_yes_no('Are you sure?','no')
 		if areyousure is False:
@@ -193,9 +206,9 @@ class MySQLRocket:
 		except mysql.Error, e:
 			print('Error %d: %s' % (e.args[0], e.args[1]))
 			sys.exit(1)
-		print '##################################'			
-		print "Database was successfully deleted!"
-		print '##################################'
+		print "-"*50		
+		print "| {0:46} |".format("Database was successfully deleted!")
+		print "-"*50
 
 	def dp(self, db_name):
 		datenow= datetime.datetime.now()
@@ -223,12 +236,12 @@ class MySQLRocket:
 			print 'MySQL connection was successful!'
 			if st_extended:
 				cursor.execute('SHOW STATUS;')
-				print '##################################'
-				print '#       MySQL Server Status      #'
-				print '##################################'
+				print "-"*50		
+				print "| {0:46} |".format("MySQL Server Status")
+				print "-"*50
 				for status in cursor.fetchall():
 					print '  '+status[0]+' = '+status[1]
-				print '##################################'
+				print "-"*50
 			cursor.close()
 			conn.close()
 
@@ -259,7 +272,7 @@ class MySQLRocket:
 		return db
 
 def launcher():
-	parser = ArgumentParser(description=ressources.__description__,prog="mysqlrocket")
+	parser = ArgumentParser(description=ressources.__description__,prog=__app_name__)
 
 	parser.add_argument("-v", "--version",  action="version",   version="%(prog)s : "+ressources.__version__ ,help="Show program version.")
 	parser.add_argument('-u', dest='mysql_user', metavar='<mysql_user>', type=str, help='mysql user')
@@ -277,6 +290,7 @@ def launcher():
 	parser_mk.add_argument('-f', '--force-password',dest='mk_db_pass', metavar='<new_user_password>', type=str, default='', help='Override random password generation')
 
 	parser_ls = subparsers.add_parser('ls', description='Show databases on MySQL server', help='Show databases on MySQL server')
+	parser_ls.add_argument('-a', '--all', action='store_true', dest='ls_db_extend', help='Show detailed information for each database')
 	parser_ls.add_argument('ls_db_pattern', metavar='<search_pattern>', type=str, nargs='?', default='%', help='Show only databases name matching pattern')
 
 	parser_rm = subparsers.add_parser('rm',description='Delete a MySQL database', help='Delete a MySQL database')
@@ -305,7 +319,7 @@ def launcher():
 	    session.mk(args.mk_db_name,args.mk_db_pass)
 
 	if hasattr(args,'ls_db_pattern'):
-	    session.ls(args.ls_db_pattern)
+	    session.ls('%'+args.ls_db_pattern+'%',args.ls_db_extend)
 
 	if hasattr(args,'rm_db_name'): 
 	    session.rm(args.rm_db_name)
