@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+__app_name__ = "mysqlrocket"
 __author__ = "Cyprien Devillez"
+__author_email__ = "cyp@bidouille.info"
 __license__ = "GPL"
-__version__ = "0.0.15"
+__version__ = "0.0.16"
 __description__ = "Simple CLI tool to create and delete easily MySQL databases."  
